@@ -2,10 +2,7 @@
 import numpy as np
 from random import randrange
 # If the code is not Cython-compiled, we need to add some imports.
-try:
-    from cython import compiled
-except ModuleNotFoundError:
-    compiled = False
+from cython import compiled
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
